@@ -3,18 +3,18 @@ import sys
 
 def print_info() -> None:
     print(
-        "Type annotations for boto3.SSM 1.17.88\n"
-        "Version:         1.17.88\n"
-        "Builder version: 4.14.1\n"
+        "Type annotations for boto3.SSM 1.17.92\n"
+        "Version:         1.17.92.post1\n"
+        "Builder version: 4.18.2\n"
         "Docs:            https://pypi.org/project/mypy-boto3-ssm/\n"
-        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/ssm.html#SSM\n"
+        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/ssm.html#SSM\n"
         "Other services:  https://pypi.org/project/boto3-stubs/\n"
         "Changelog:       https://github.com/vemel/mypy_boto3_builder/releases"
     )
 
 
 def print_version() -> None:
-    print("1.17.88")
+    print("1.17.92.post1")
 
 
 def main() -> None:
