@@ -1,7 +1,7 @@
 """
 Type annotations for ssm service client waiters.
 
-[Open documentation](./waiters.md)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm/waiters.html)
 
 Usage::
 
@@ -27,17 +27,18 @@ __all__ = ("CommandExecutedWaiter",)
 
 class CommandExecutedWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/ssm.html#SSM.Waiter.command_executed)[Show boto3-stubs documentation](./waiters.md#commandexecutedwaiter)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/ssm.html#SSM.Waiter.command_executed)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm/waiters.html#commandexecutedwaiter)
     """
 
     def wait(
         self,
+        *,
         CommandId: str,
         InstanceId: str,
         PluginName: str = None,
-        WaiterConfig: WaiterConfigTypeDef = None,
+        WaiterConfig: WaiterConfigTypeDef = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/ssm.html#SSM.Waiter.CommandExecutedWaiter)
-        [Show boto3-stubs documentation](./waiters.md#commandexecuted)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/ssm.html#SSM.Waiter.CommandExecutedWaiter)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm/waiters.html#commandexecuted)
         """
